@@ -35,12 +35,13 @@
 #include <gio/gdesktopappinfo.h>
 #include "src/Interface/ukuimenuinterface.h"
 #include "src/UtilityFunction/scrollarea.h"
-#include "src/UtilityFunction/pushbutton.h"
+#include "src/UtilityFunction/splitbarframe.h"
 #include "src/UtilityFunction/fulllistview.h"
-#include "src/UtilityFunction/classifyscrollarea.h"
+#include "src/UtilityFunction/classifybtnscrollarea.h"
 #include "src/UtilityFunction/toolbutton.h"
 #include "src/UtilityFunction/functionclassifybutton.h"
 #include "src/Style/style.h"
+#include <QAbstractButton>
 
 class FullFunctionWidget : public QWidget
 {
@@ -73,29 +74,38 @@ public:
      */
     void setFunctionBtnGeometry();
 
+    void functionButtonClick();
+
+    QAbstractButton* getCurLetterButton(int value);
+
 private:
     /*Application list interface*/
     UkuiMenuInterface* m_ukuiMenuInterface=nullptr;
     QWidget* m_applistWid=nullptr;
     ScrollArea* m_scrollArea=nullptr;
-    QWidget* m_scrollAreaWid=nullptr;
+    ScrollAreaWid* m_scrollAreaWid=nullptr;
     QVBoxLayout* m_scrollAreaWidLayout=nullptr;
     QStringList m_classificationList;//Store the list of category buttons
     QStringList m_data;
-
+    QTimer *time = nullptr;
+    bool flag;
     /*Function classification list interface*/
     QWidget* m_iconListWid=nullptr;
-    ClassifyScrollArea* m_iconListScrollArea=nullptr;
-    QWidget* m_iconListScrollAreaWid=nullptr;
+    ClassifyBtnScrollArea* m_iconListScrollArea=nullptr;
+    ClassifyBtnScrollAreaWid* m_iconListScrollAreaWid=nullptr;
     QVBoxLayout* m_iconListScrollAreaWidLayout=nullptr;
     QList<QAbstractButton*> m_buttonList;
     QButtonGroup* m_btnGroup=nullptr;
+    QSpacerItem* m_topSpacerItem=nullptr;
+    QSpacerItem* m_bottomSpacerItem=nullptr;
+    QSpacerItem* m_appListBottomSpacer=nullptr;
 
     /*Animation*/
     QPropertyAnimation* m_animation=nullptr;//Function category button animation
     QPropertyAnimation* m_scrollAnimation=nullptr;//Application list animation
-    int m_beginPos=0;//Application list scrollbar starting value
-    int m_endPos=0;//Application list scrollbar end value
+    int m_beginPos= 0;//Application list scrollbar starting value
+    int m_endPos= 0;//Application list scrollbar end value
+    int m_index = 0;
 
 protected:
     /**
@@ -107,7 +117,6 @@ protected:
      */
     void initIconListWidget();
     void initIconListScrollArea();
-
     /**
      * @brief Initialize the application list interface
      */
@@ -131,6 +140,8 @@ protected:
      */
     void resizeScrollAreaControls();
 
+    bool eventFilter(QObject *watched, QEvent *event);
+
 public Q_SLOTS:
     /**
      * @brief Open the application
@@ -161,11 +172,19 @@ public Q_SLOTS:
      */
     void animationValueChangedSlot(const QVariant &value);
 
+    void onSetSlider(int);
+
+    void setFocusToThis();
+
 Q_SIGNALS:
     /**
      * @brief Send a hidden main window signal to the MainViewWidget
      */
     void sendHideMainWindowSignal();
+
+    void setFocusToSideWin();
+
+    void selectFirstItem();
 };
 
 #endif // FULLFUNCTIONWIDGET_H
