@@ -43,9 +43,9 @@
 #include <gio/gdesktopappinfo.h>
 #include "src/UtilityFunction/letterclassifybutton.h"
 #include "src/UtilityFunction/scrollarea.h"
-#include "src/UtilityFunction/pushbutton.h"
+#include "src/UtilityFunction/splitbarframe.h"
 #include "src/UtilityFunction/fulllistview.h"
-#include "src/UtilityFunction/classifyscrollarea.h"
+#include "src/UtilityFunction/classifybtnscrollarea.h"
 #include "src/UtilityFunction/toolbutton.h"
 #include "src/Style/style.h"
 
@@ -80,24 +80,31 @@ public:
      */
     void setLetterBtnGeometry();
 
+    void letterButtonClick();
+
+    QAbstractButton* getCurLetterButton(int value);
+
 private:
     /*Application list interface*/
     UkuiMenuInterface* m_ukuiMenuInterface=nullptr;
     QWidget* m_applistWid=nullptr;
     ScrollArea* m_scrollArea=nullptr;
-    QWidget* m_scrollAreaWid=nullptr;
+    ScrollAreaWid* m_scrollAreaWid=nullptr;
     QVBoxLayout* m_scrollAreaWidLayout=nullptr;
     QStringList m_letterList;//Store the list of letter buttons
     QStringList m_data;
-
+    bool flag;
+    QTimer *time = nullptr;
+    int m_index = 0;
     /*Alphabetic classification list interface*/
     QWidget* m_letterListWid=nullptr;
-    ClassifyScrollArea* m_letterListScrollArea=nullptr;
-    QWidget* m_letterListScrollAreaWid=nullptr;
+    ClassifyBtnScrollArea* m_letterListScrollArea=nullptr;
+    ClassifyBtnScrollAreaWid* m_letterListScrollAreaWid=nullptr;
     QVBoxLayout* m_letterListScrollAreaWidLayout=nullptr;
     QList<QAbstractButton*> m_buttonList;
     QButtonGroup* m_btnGroup=nullptr;
     QSpacerItem* m_letterListBottomSpacer=nullptr;
+    QSpacerItem* m_appListBottomSpacer=nullptr;
 
     /*Animation*/
     QPropertyAnimation* m_animation=nullptr;//Letter category button animation
@@ -110,6 +117,7 @@ protected:
      * @brief Initializes UI
      */
     void initUi();
+//    void paintEvent(QPaintEvent *event);
     /**
      * @brief fill application list
      */
@@ -128,6 +136,8 @@ protected:
      */
     void resizeScrollAreaControls();
 
+    bool eventFilter(QObject *watched, QEvent *event);
+
 public Q_SLOTS:
     /**
      * @brief Respond to button click
@@ -158,11 +168,22 @@ public Q_SLOTS:
      */
     void animationValueChangedSlot(const QVariant &value);
 
+    void onSetSlider(int);
+
+    void setFocusToThis();
+public:
 Q_SIGNALS:
     /**
      * @brief Send a hidden main window signal to the MainViewWidget
      */
     void sendHideMainWindowSignal();
+    /**
+     * @brief setFocusToMainWin
+     */
+    void setFocusToSideWin();
+
+    void selectFirstItem();
+
 };
 
 #endif // FULLLETTERWIDGET_H
