@@ -28,6 +28,7 @@
 #include <QGraphicsDropShadowEffect>
 #include <syslog.h>
 #include "src/UtilityFunction/itemdelegate.h"
+#include "src/UtilityFunction/utility.h"
 
 LetterWidget::LetterWidget(QWidget *parent) :
     QWidget(parent)
@@ -47,7 +48,6 @@ void LetterWidget::initUi()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
     this->setAttribute(Qt::WA_StyledBackground,true);
-    this->setStyleSheet("border:0px;background:transparent;");
     this->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
     this->setFixedSize(Style::defaultMainViewWidWidth,Style::defaultContentWidHeight);
 
@@ -72,12 +72,13 @@ void LetterWidget::initUi()
  */
 void LetterWidget::initAppListWidget()
 {
-    m_appListView=new ListView(this,this->width()-4,this->height(),1);
-    m_appListView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    m_appListView=new ListView(this,this->width()-6,this->height()-6,1);
+    m_appListView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_appListView->show();
     fillAppListView();
     connect(m_appListView,&ListView::sendItemClickedSignal,this,&LetterWidget::recvItemClickedSlot);
     connect(m_appListView,&ListView::sendHideMainWindowSignal,this,&LetterWidget::sendHideMainWindowSignal);
+    connect(m_appListView,&ListView::sendMainWinActiveSignal,this,&LetterWidget::sendMainWinActiveSignal);
 }
 
 
@@ -86,6 +87,7 @@ void LetterWidget::initAppListWidget()
  */
 void LetterWidget::fillAppListView()
 {
+    m_data.clear();
     int row=0;
     QVector<QStringList> vector=UkuiMenuInterface::alphabeticVector;
     for(int i=0;i<vector.size();i++)
@@ -127,14 +129,7 @@ void LetterWidget::recvItemClickedSlot(QStringList arg)
 void LetterWidget::execApplication(QString desktopfp)
 {
     Q_EMIT sendHideMainWindowSignal();
-    GDesktopAppInfo * desktopAppInfo=g_desktop_app_info_new_from_filename(desktopfp.toLocal8Bit().data());
-    bool ret=g_app_info_launch(G_APP_INFO(desktopAppInfo),nullptr, nullptr, nullptr);
-    g_object_unref(desktopAppInfo);
-    syslog(LOG_LOCAL0 | LOG_DEBUG ,"执行应用程序 %s:%d:%s:%s",
-           desktopfp.toLocal8Bit().data(),
-           ret,
-           m_ukuiMenuInterface->getAppExec(desktopfp).toLocal8Bit().data(),
-           m_ukuiMenuInterface->getAppIcon(desktopfp).toLocal8Bit().data());
+    execApp(desktopfp);
 }
 
 /**
@@ -176,18 +171,18 @@ void LetterWidget::updateAppListView()
  */
 void LetterWidget::appClassificationBtnClickedSlot()
 {
-    m_leaveAnimation->setStartValue(QRect(0,0,this->width()-4,this->height()));
-    m_leaveAnimation->setEndValue(QRect(20,20,this->width()-40,this->height()-40));
+    m_leaveAnimation->setStartValue(QRect(6,0,this->width()-6,this->height()-6));
+    m_leaveAnimation->setEndValue(QRect(6,0,this->width()-6,this->height()-6));
+//    m_leaveAnimation->setEndValue(QRect(20,20,this->width()-40,this->height()-40));
     m_enterAnimation->setStartValue(QRect(-40,-40,this->width()+80,this->height()+80));
     m_enterAnimation->setEndValue(QRect((this->width()-235)/2,(this->height()-366)/2,235,366));
-    m_leaveAnimation->setDuration(10);
-    m_enterAnimation->setDuration(80);
 
     //加载LetterBUttonWidget界面
+    m_enterAnimation->setDuration(100);
+    m_leaveAnimation->setDuration(10);
     Q_EMIT sendLetterBtnList(m_letterList);
     m_leaveAnimation->setTargetObject(m_appListView);
     m_enterAnimation->setTargetObject(m_letterBtnWid);
-    m_letterBtnWid->setWindowOpacity(0.1);
     m_leaveAnimation->start();
     m_widgetState=1;
 }
@@ -207,11 +202,12 @@ void LetterWidget::recvLetterBtnSlot(QString btnname)
 
     m_leaveAnimation->setStartValue(QRect((this->width()-235)/2,(this->height()-366)/2,235,366));
     m_leaveAnimation->setEndValue(QRect(-40,-40,this->width()+80,this->height()+80));
-    m_enterAnimation->setStartValue(QRect(20,20,this->width()-40,this->height()-40));
-    m_enterAnimation->setEndValue(QRect(0,0,this->width()-4,this->height()));
-    m_leaveAnimation->setDuration(80);
-    m_enterAnimation->setDuration(10);
+//    m_enterAnimation->setStartValue(QRect(16,10,this->width()-20,this->height()-20));
+    m_enterAnimation->setStartValue(QRect(6,0,this->width()-6,this->height()-6));
+    m_enterAnimation->setEndValue(QRect(6,0,this->width()-6,this->height()-6));
 
+    m_enterAnimation->setDuration(10);
+    m_leaveAnimation->setDuration(100);
     m_leaveAnimation->setTargetObject(m_letterBtnWid);
     m_enterAnimation->setTargetObject(m_appListView);
     m_leaveAnimation->start();
@@ -239,7 +235,7 @@ void LetterWidget::animationFinishedSLot()
 void LetterWidget::widgetMakeZero()
 {
     m_letterBtnWid->hide();
-    m_appListView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    m_appListView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_appListView->show();
     m_appListView->verticalScrollBar()->setValue(0);
 }
@@ -255,6 +251,11 @@ void LetterWidget::moveScrollBar(int type)
 void LetterWidget::repaintWidget()
 {
     this->setFixedSize(Style::defaultMainViewWidWidth,Style::defaultContentWidHeight);
-    m_appListView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    m_appListView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_appListView->show();
 }
+
+void LetterWidget::setFocusToThis()
+{
+    this->setFocus();
+}
