@@ -33,15 +33,6 @@ public:
 
 private:
     UkuiMenuInterface *m_ukuiMenuInterface=nullptr;
-    QString m_path;
-    QSettings* setting=nullptr;
-
-public Q_SLOTS:
-    /**
-     * @brief Receive the changed directory
-     * @param arg: Desktop file directory
-     */
-    void recvDirectoryPath(QString arg);
 
 Q_SIGNALS:
     /**
