@@ -30,6 +30,7 @@
 #include "src/Interface/ukuimenuinterface.h"
 #include "src/UtilityFunction/fulllistview.h"
 #include "src/Style/style.h"
+#include "src/UtilityFunction/scrollarea.h"
 
 class FullSearchResultWidget : public QWidget
 {
@@ -54,17 +55,24 @@ public:
      */
     void moveScrollBar(int type);
 
+    void setViewFocus();
+
 private:
     UkuiMenuInterface* m_ukuiMenuInterface=nullptr;
     FullListView* m_listView=nullptr;
     QStringList m_data;
     QSpacerItem *m_spaceItem=nullptr;
 
+    ScrollArea* m_scrollArea=nullptr;
+    ScrollAreaWid* m_scrollAreaWid=nullptr;
+    QVBoxLayout* m_scrollAreaWidLayout=nullptr;
+
 protected:
     /**
      * @brief Initializes UI
      */
     void initUi();
+    void resizeScrollAreaControls();
 
 private Q_SLOTS:
     /**
