@@ -20,6 +20,7 @@
 #include "src/Style/style.h"
 #include <QDebug>
 #include <QHeaderView>
+#include "src/UtilityFunction/utility.h"
 
 SearchResultWidget::SearchResultWidget(QWidget *parent) :
     QWidget(parent)
@@ -36,12 +37,11 @@ void SearchResultWidget::initUi()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
     this->setAttribute(Qt::WA_StyledBackground,true);
-    this->setStyleSheet("border:0px;background:transparent;");
     this->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
     this->setFixedSize(Style::defaultMainViewWidWidth,Style::defaultContentWidHeight);
-
-    m_listView=new ListView(this,this->width()-4,this->height(),3);
-    m_listView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    this->setFocusPolicy(Qt::StrongFocus);
+    m_listView=new ListView(this,this->width()-6,this->height()-6,3);
+    m_listView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_listView->show();
 
     m_data.clear();
@@ -59,9 +59,7 @@ void SearchResultWidget::execApplication(QStringList arg)
 {
     Q_EMIT sendHideMainWindowSignal();
     QString desktopfp=arg.at(0);
-    GDesktopAppInfo * desktopAppInfo=g_desktop_app_info_new_from_filename(desktopfp.toLocal8Bit().data());
-    g_app_info_launch(G_APP_INFO(desktopAppInfo),nullptr, nullptr, nullptr);
-    g_object_unref(desktopAppInfo);
+    execApp(desktopfp);
 }
 
 void SearchResultWidget::updateAppListView(QVector<QStringList> arg)
@@ -83,6 +81,11 @@ void SearchResultWidget::moveScrollBar(int type)
 void SearchResultWidget::repaintWidget()
 {
     this->setFixedSize(Style::defaultMainViewWidWidth,Style::defaultContentWidHeight);
-    m_listView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    m_listView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_listView->show();
 }
+
+void SearchResultWidget::setViewFocus()
+{
+    m_listView->setFocus();
+}
