@@ -22,6 +22,7 @@
 #include <QPainter>
 #include <QPainterPath>
 #include <syslog.h>
+#include <QShortcut>
 #include "src/Style/style.h"
 #include "src/UtilityFunction/utility.h"
 
@@ -35,8 +36,8 @@ SideBarWidget::SideBarWidget(QWidget *parent) :
 SideBarWidget::~SideBarWidget()
 {
     delete m_ukuiMenuInterface;
-    delete m_shutDownMenu;
-    delete m_otherMenu;
+//    delete m_shutDownMenu;
+//    delete m_otherMenu;
 }
 
 /**
@@ -46,17 +47,57 @@ void SideBarWidget::initUi()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
     this->setAttribute(Qt::WA_StyledBackground,true);
-    this->setStyleSheet("border:0px;background:transparent;");
     this->setFocusPolicy(Qt::NoFocus);
 
     addSidebarBtn();
     loadMinSidebar();
-
+    m_minMaxBtn->installEventFilter(this);
+    m_allBtn->installEventFilter(this);
+    m_letterBtn->installEventFilter(this);
+    m_functionBtn->installEventFilter(this);
+    m_userIconBtn->installEventFilter(this);
+    m_computerBtn->installEventFilter(this);
+    m_personalBtn->installEventFilter(this);
+    m_controlBtn->installEventFilter(this);
+    m_trashBtn->installEventFilter(this);
+    m_shutDownBtn->installEventFilter(this);
     m_ukuiMenuInterface=new UkuiMenuInterface;
-    m_shutDownMenu=new RightClickMenu;
-    m_otherMenu=new RightClickMenu;
+ //   m_shutDownMenu=new RightClickMenu;
+ //   m_otherMenu=new RightClickMenu;
 }
 
+bool SideBarWidget::eventFilter(QObject * target , QEvent * event )
+{
+
+    if( event->type() == QEvent::KeyPress )
+    {
+        QKeyEvent *ke = (QKeyEvent *)event;
+        if( ke->key() == Qt::Key_Tab )
+        {
+            Q_EMIT setFocusToMainWin();
+         //   return true;
+        }
+        if(ke->key() == Qt::Key_Up || ke->key() == Qt::Key_Left)
+        {
+            if(m_minMaxBtn->hasFocus())
+            {
+                m_shutDownBtn->setFocus();
+                return true;
+            }
+        }
+        if(ke->key() == Qt::Key_Down || ke->key() == Qt::Key_Right)
+        {
+            if(m_shutDownBtn->hasFocus())
+            {
+               this->setFocus();
+            }
+        }
+    }
+    return QWidget::eventFilter(target , event);
+}
+
+
+
 /**
  * 侧边栏添加控件
  */
@@ -65,32 +106,39 @@ void SideBarWidget::addSidebarBtn()
     m_mainWidget=new QWidget;
     m_mainWidget->setParent(this);
     m_mainWidgetLayout=new QVBoxLayout;
-    m_mainWidgetLayout->setContentsMargins(0,0,0,0);
+    m_mainWidgetLayout->setContentsMargins(0,0,0,6);
     m_mainWidgetLayout->setSpacing(10);
     m_mainWidget->setLayout(m_mainWidgetLayout);
-    m_mainWidget->setStyleSheet("background:transparent;");
-
+  //  m_mainWidget->setFocusPolicy(Qt::StrongFocus);
+//    m_mainWidget->setAutoFillBackground(true);
+//    QPalette palette;
+//    palette.setBrush(QPalette::Background,Qt::red);
+//    m_mainWidget->setPalette(palette);
     //放大缩小按钮界面
     m_minMaxWidget=new QWidget;
-    m_minMaxWidget->setStyleSheet("QWidget{background:transparent;border:0px;}");
     m_minMaxLayout=new QHBoxLayout;
-    m_minMaxBtn=new QToolButton;
+    m_minMaxBtn=new QPushButton;
+    m_minMaxBtn->setFlat(true);
+    m_minMaxBtn->setProperty("useButtonPalette", true);
+//    m_minMaxBtn->setProperty("doNotAnimate",true);
+//    m_minMaxBtn->setProperty("useButtonPalette", true);
+//    m_minMaxBtn->setFlat(true);
+//    m_minMaxBtn->setProperty("doNotAnimate",true);
 //    m_minMaxBtn->setShortcut(QKeySequence::InsertParagraphSeparator);
+
 //    m_minMaxBtn->setShortcut(Qt::Key_Enter);
-    m_minMaxBtn->setShortcut(Qt::Key_Return);
+//    m_minMaxBtn->setShortcut(Qt::Key_Return);
+//    QShortcut *key_1 = new QShortcut(QKeySequence(Qt::Key_Enter),this);
+//    connect(key_1,&QShortcut::activated,m_minMaxBtn,&QPushButton::click);
+//    QShortcut *key_2 = new QShortcut(QKeySequence(Qt::Key_Return),this);
+//    connect(key_2,&QShortcut::activated,m_minMaxBtn,&QPushButton::click);
     m_minMaxLayout->addWidget(m_minMaxBtn);
     m_minMaxWidget->setLayout(m_minMaxLayout);
-    char btncolor[300];
-    sprintf(btncolor,"QToolButton{background:transparent;border:0px;padding-left:0px;border-radius:4px;}\
-            QToolButton:hover{background-color:%s;border:0px;border-radius:4px;}\
-            QToolButton:pressed{background-color:%s;border:0px;border-radius:4px;}",
-            MMBtnHoverBackground,MMBtnHoverBackground);
-    m_minMaxBtn->setStyleSheet(QString::fromLocal8Bit(btncolor));
+//    m_minMaxWidget->setAttribute(Qt::WA_StyledBackground,true);
+//    m_minMaxWidget->hasFocus();
 
     //分类按钮
     m_buttonList.clear();
-//    m_buttonTextList.clear();
-    m_btnGroup=new QButtonGroup(m_mainWidget);
     m_allBtn=new QPushButton;
     initBtn(m_allBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/commonuse.svg"),tr("All"),0);
     m_letterBtn=new QPushButton;
@@ -99,24 +147,27 @@ void SideBarWidget::addSidebarBtn()
     initBtn(m_functionBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/function.svg"),tr("Function"),2);
     int id=0;
     Q_FOREACH (QAbstractButton* btn, m_buttonList) {
-        m_btnGroup->addButton(btn,id++);
+      //  m_btnGroup->addButton(btn,id++);
+        btn->setCheckable(true);
     }
 
-    QString usericon=m_ukuiMenuInterface->getUserIcon();
-    QString username=m_ukuiMenuInterface->getUserName();
+    QString usericon=getUserIcon();
+    QString username=getUserName();
     m_userIconBtn=new QPushButton;
     initBtn(m_userIconBtn,usericon,username,3);
     m_personalBtn=new QPushButton;
     initBtn(m_personalBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/personal.svg"),tr("Personal"),4);
     m_trashBtn=new QPushButton;
-    initBtn(m_trashBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/trash.svg"),tr("Recycle Bin"),5);
+    initBtn(m_trashBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/trash.svg"),tr("Trash"),5);
     m_computerBtn=new QPushButton;
     initBtn(m_computerBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/computer.svg"),tr("Computer"),6);
     m_controlBtn=new QPushButton;
     initBtn(m_controlBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/control.svg"),tr("Settings"),7);
     m_shutDownBtn=new QPushButton;
     initBtn(m_shutDownBtn,QString::fromLocal8Bit(":/data/img/sidebarwidget/shutdown.svg"),tr("Power"),8);
-    connect(m_btnGroup,static_cast<void(QButtonGroup::*)(QAbstractButton*)>(&QButtonGroup::buttonClicked),this,&SideBarWidget::btnGroupClickedSlot);
+    connect(m_allBtn, &QPushButton::clicked, this, &SideBarWidget::btnAllClickedSlot);
+    connect(m_letterBtn ,&QPushButton::clicked, this, &SideBarWidget::btnLetterClickedSlot);
+    connect(m_functionBtn, &QPushButton::clicked, this, &SideBarWidget::btnFuncClickedSlot);
     connect(m_computerBtn,&QPushButton::clicked,this,&SideBarWidget::computerBtnClickedSlot);
     connect(m_personalBtn,&QPushButton::clicked,this,&SideBarWidget::personalBtnClickedSlot);
     connect(m_controlBtn,&QPushButton::clicked,this,&SideBarWidget::controlBtnClickedSlot);
@@ -128,7 +179,10 @@ void SideBarWidget::addSidebarBtn()
     {
         QPushButton* btn=qobject_cast<QPushButton*>(button);
         if(m_buttonList.indexOf(button)>3 && m_buttonList.indexOf(button)<m_buttonList.count()-1)
+        {
+            button->setCheckable(false);
             addRightClickMenu(btn);
+        }
     }
     m_shutDownBtn->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(m_shutDownBtn,&QPushButton::customContextMenuRequested,this,
@@ -169,6 +223,12 @@ void SideBarWidget::addSidebarBtn()
     }
     m_mainWidgetLayout->addWidget(m_buttonList.at(8));
 
+    if(QGSettings::isSchemaInstalled(QString("org.ukui.style").toLocal8Bit()))
+    {
+        QGSettings* gsetting=new QGSettings(QString("org.ukui.style").toLocal8Bit());
+        connect(gsetting,&QGSettings::changed,this,&SideBarWidget::themeModeChangeSlot);
+    }
+
     m_animation = new QPropertyAnimation(m_mainWidget, "geometry");
 }
 
@@ -201,20 +261,20 @@ void SideBarWidget::resetSidebarBtnSlot()
  */
 void SideBarWidget::initBtn(QPushButton *btn, QString btnicon, QString text, int num)
 {
-    char btncolor[300];
-    sprintf(btncolor,"QPushButton{background:transparent;border:0px;padding-left:0;border-radius:4px;}\
-            QPushButton:hover{background-color:%s;border:0px;border-radius:4px;}\
-            QPushButton:pressed{background-color:%s;border:0px;border-radius:4px;}",
-            SBFunBtnHoverBackground,SBFunBtnHoverBackground);
-    btn->setStyleSheet(QString::fromLocal8Bit(btncolor));
+    btn->setFlat(true);
+    btn->setProperty("useButtonPalette",true);
     QHBoxLayout* btnLayout=new QHBoxLayout;
     QLabel* labelicon=new QLabel;
     labelicon->setAlignment(Qt::AlignCenter);
-    labelicon->setStyleSheet("background:transparent;border:0px;");
     const auto ratio=devicePixelRatioF();
+    QGSettings gsetting(QString("org.ukui.style").toLocal8Bit());
     if(num!=3)
     {
         QPixmap pixmap=loadSvg(btnicon,Style::SideBarIconSize*ratio);
+        if(gsetting.get("style-name").toString()=="ukui-light")//反黑
+            pixmap=drawSymbolicBlackColoredPixmap(pixmap);
+        else
+            pixmap=drawSymbolicColoredPixmap(pixmap);//反白
         pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
         labelicon->setFixedSize(Style::SideBarIconSize,Style::SideBarIconSize);
         labelicon->setPixmap(pixmap);
@@ -222,7 +282,7 @@ void SideBarWidget::initBtn(QPushButton *btn, QString btnicon, QString text, int
     else {
         if(!QFile::exists(btnicon))
             btnicon=QString("/usr/share/ukui/faces/default.png");
-        labelicon->setObjectName(QStringLiteral("faceLabel"));
+        labelicon->setObjectName("faceLabel");
         labelicon->setFocusPolicy(Qt::NoFocus);
         labelicon->setAlignment(Qt::AlignCenter);
         labelicon->setFixedSize(Style::SideBarIconSize+4,Style::SideBarIconSize+4);
@@ -236,12 +296,22 @@ void SideBarWidget::initBtn(QPushButton *btn, QString btnicon, QString text, int
 
     btnLayout->setSpacing(0);
     btnLayout->addWidget(labelicon);
+//    btnLayout->addStretch();
+
+    QLabel* textLabel=new QLabel;
+    if(num==3)
+        textLabel->setObjectName("nameLabel");
+    textLabel->setText(text);
+    btnLayout->addWidget(textLabel);
     btnLayout->addStretch();
+
     btn->setLayout(btnLayout);
-    btn->setFocusPolicy(Qt::NoFocus);
+    btn->setFocusPolicy(Qt::StrongFocus);
 
     m_buttonList.append(btn);
     m_textList.append(text);
+
+    m_labelList.append(textLabel);
 }
 
 QPixmap SideBarWidget::PixmapToRound(const QPixmap &src, int radius)
@@ -266,10 +336,14 @@ QPixmap SideBarWidget::PixmapToRound(const QPixmap &src, int radius)
 /**
  * 加载关机按钮右键菜单
  */
-void SideBarWidget::shutdownBtnRightClickSlot()
+void SideBarWidget::shutdownBtnRightClickSlot(const QPoint &pos)
 {
-    int ret=m_shutDownMenu->showShutdownMenu();
-    if(ret>=10 && ret<=14)
+
+    RightClickMenu m_otherMenu(this);
+    int ret = m_otherMenu.showShutdownMenu(m_shutDownBtn->mapToGlobal(pos));
+    Q_EMIT sendShowMainWindowSignal(false);
+    qDebug() << "SideBarWidget::shutdownBtnRightClickSlot() 开始";
+    if(ret>=10 && ret<=17)
     {
         Q_EMIT sendHideMainWindowSignal();
         switch (ret) {
@@ -289,7 +363,7 @@ void SideBarWidget::shutdownBtnRightClickSlot()
             QProcess::startDetached(QString("ukui-session-tools --shutdown"));
             break;
         case 16:
-            QProcess::startDetached(QString("ukui-session-tools --hibernate"));
+            QProcess::startDetached(QString("ukui-session-tools --suspend"));
             break;
         case 17:
             QProcess::startDetached(QString("ukui-session-tools --sleep"));
@@ -299,17 +373,18 @@ void SideBarWidget::shutdownBtnRightClickSlot()
         }
 
     }
+    qDebug() << "SideBarWidget::shutdownBtnRightClickSlot() 结束";
 }
 
 void SideBarWidget::addRightClickMenu(QPushButton *btn)
 {
     btn->setContextMenuPolicy(Qt::CustomContextMenu);
-//    disconnect(btn,&QPushButton::customContextMenuRequested,this,&SideBarWidget::otherBtnRightClickSlot);
     connect(btn,&QPushButton::customContextMenuRequested,this,&SideBarWidget::otherBtnRightClickSlot);
 }
 
-void SideBarWidget::otherBtnRightClickSlot()
+void SideBarWidget::otherBtnRightClickSlot(const QPoint &pos)
 {
+    qDebug() << "SideBarWidget::otherBtnRightClickSlot() 开始";
     QPushButton* btn=dynamic_cast<QPushButton*>(QObject::sender());
     int index=m_buttonList.indexOf(btn);
     QString desktopfp;
@@ -329,12 +404,15 @@ void SideBarWidget::otherBtnRightClickSlot()
     default:
         break;
     }
-    int ret=m_otherMenu->showOtherMenu(desktopfp);
+    RightClickMenu m_otherMenu;
+    int ret = m_otherMenu.showOtherMenu(btn->mapToGlobal(pos), desktopfp);
+    Q_EMIT sendShowMainWindowSignal(false);
     if(ret==15)
     {
         Q_EMIT sendHideMainWindowSignal();
         QProcess::startDetached(QString("ukui-control-center -d"));
     }
+    qDebug() << "SideBarWidget::otherBtnRightClickSlot() 结束";
 }
 
 void SideBarWidget::computerBtnClickedSlot()
@@ -352,14 +430,7 @@ void SideBarWidget::personalBtnClickedSlot()
 void SideBarWidget::controlBtnClickedSlot()
 {
     Q_EMIT sendHideMainWindowSignal();
-    QString execpath=m_ukuiMenuInterface->getAppExec(QString("/usr/share/applications/ukui-control-center.desktop"));
-    //移除启动参数%u或者%U
-    if(execpath.contains("%"))
-    {
-        int index=execpath.indexOf(QString("%").at(0));
-        execpath.remove(index-1,3);
-    }
-    QProcess::startDetached(execpath);
+    execApp("/usr/share/applications/ukui-control-center.desktop");
 
 }
 
@@ -384,19 +455,20 @@ void SideBarWidget::userIconBtnClickedSlot()
 void SideBarWidget::userAccountsChanged()
 {
     const auto ratio=devicePixelRatioF();
-    QString usericon=m_ukuiMenuInterface->getUserIcon();
+    QString usericon=getUserIcon();
     if(!QFile::exists(usericon))
         usericon=QString("/usr/share/ukui/faces/default.png");
     QPixmap facePixmap(usericon);
-    facePixmap = facePixmap.scaled((Style::SideBarIconSize+4)*ratio,(Style::SideBarIconSize+4)*ratio, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-    facePixmap = PixmapToRound(facePixmap, (Style::SideBarIconSize+4)*ratio/2);
+    facePixmap = facePixmap.scaled((Style::SideBarIconSize + 2)*ratio,(Style::SideBarIconSize + 2)*ratio, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    facePixmap = PixmapToRound(facePixmap, (Style::SideBarIconSize + 2)*ratio/2);
 
-//    QLayoutItem* item=m_userIconBtn->layout()->itemAt(0);
-//    QLabel* labelicon=qobject_cast<QLabel*>(item->widget());
-//    labelicon->setScaledContents(true);
     QLabel* labelicon=m_userIconBtn->findChild<QLabel*>("faceLabel");
     facePixmap.setDevicePixelRatio(qApp->devicePixelRatio());
     labelicon->setPixmap(facePixmap);
+    QLabel* labelname=m_userIconBtn->findChild<QLabel*>("nameLabel");
+    QString userName = fontMetrics().elidedText(getUserName(),Qt::ElideRight,labelname->width()-10,Qt::TextShowMnemonic);
+    labelname->setText(userName);//更新用户名
+    m_textList.replace(3,getUserName());//更新用户名
 }
 
 /**
@@ -407,20 +479,25 @@ void SideBarWidget::loadMinSidebar()
     m_isFullScreen=false;
     setMaxBtn();
 
+    m_animation->stop();
     this->setFixedSize(Style::defaultSideBarWidWidth,Style::minh);
     m_mainWidget->setGeometry(QRect(0,0,this->width(),this->height()));
     m_mainWidget->show();
     m_minMaxWidget->setFixedSize(37,70);
     m_minMaxLayout->setContentsMargins(0,0,0,0);
 
-    m_mainWidgetLayout->setContentsMargins(8,0,10,0);
+    m_mainWidgetLayout->setContentsMargins(8,0,10,6);
 
     Q_FOREACH(QAbstractButton* button,m_buttonList)
     {
         QPushButton* btn=qobject_cast<QPushButton*>(button);
         setMinSidebarBtn(btn);
+        btn->setToolTip(m_textList.at(m_buttonList.indexOf(button)));
     }
 
+
+    changeIconColor(false);
+
     disconnect(m_minMaxBtn,&QToolButton::clicked,this, &SideBarWidget::sendDefaultBtnSignal);
     connect(m_minMaxBtn, &QToolButton::clicked,this,&SideBarWidget::sendFullScreenBtnSignal);
 }
@@ -430,14 +507,20 @@ void SideBarWidget::loadMinSidebar()
  */
 void SideBarWidget::setMaxBtn()
 {
+    const auto ratio=devicePixelRatioF();
+    QGSettings gsetting(QString("org.ukui.style").toLocal8Bit());
+    QPixmap pixmap=loadSvg(QString(":/data/img/sidebarwidget/max.svg"),14*ratio);
+    if(gsetting.get("style-name").toString()=="ukui-light")//反黑
+        pixmap=drawSymbolicBlackColoredPixmap(pixmap);
+    else
+        pixmap=drawSymbolicColoredPixmap(pixmap);//反白
+    pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
+
     m_minMaxBtn->setFixedSize(37,37);
-    QSvgRenderer* svgRender = new QSvgRenderer(m_minMaxBtn);
-    svgRender->load(QString(":/data/img/sidebarwidget/max.svg"));
-    QPixmap* pixmap = new QPixmap(14,14);
-    pixmap->fill(Qt::transparent);//设置背景透明
-    QPainter p(pixmap);
-    svgRender->render(&p);
-    m_minMaxBtn->setIcon(QIcon(*pixmap));
+    m_minMaxBtn->setIcon(QIcon(pixmap));
+    m_minMaxBtn->setToolTip(tr("Max"));
+
+//    m_minMaxBtn->setFocus();
 }
 
 /**
@@ -445,7 +528,6 @@ void SideBarWidget::setMaxBtn()
  */
 void SideBarWidget::setMinSidebarBtn(QPushButton* btn)
 {
-    const auto ratio=devicePixelRatioF();
     btn->setFixedSize(37,37);
     if(m_buttonList.indexOf(btn)==3)
         btn->layout()->setContentsMargins(7,0,17,0);
@@ -453,18 +535,20 @@ void SideBarWidget::setMinSidebarBtn(QPushButton* btn)
         btn->layout()->setContentsMargins(9,0,17,0);
     btn->layout()->setSpacing(0);
 
+    m_labelList.at(m_buttonList.indexOf(btn))->setVisible(false);
+
     //移除按钮文本
-    QLayoutItem *child;
-    if((child = btn->layout()->takeAt(1)) != nullptr) {
-        QWidget* childwid=child->widget();
-        if(childwid!=nullptr)
-        {
-            btn->layout()->removeWidget(childwid);
-            childwid->setParent(nullptr);
-            delete childwid;
-            delete child;
-        }
-    }
+//    QLayoutItem *child;
+//    if((child = btn->layout()->takeAt(1)) != nullptr) {
+//        QWidget* childwid=child->widget();
+//        if(childwid!=nullptr)
+//        {
+//            btn->layout()->removeWidget(childwid);
+//            childwid->setParent(nullptr);
+//            delete childwid;
+//            delete child;
+//        }
+//    }
 }
 
 /**
@@ -480,7 +564,7 @@ void SideBarWidget::loadMaxSidebar()
     m_minMaxWidget->setFixedSize(Style::MinMaxWidWidth,Style::MinMaxWidHeight);
     m_minMaxLayout->setContentsMargins(m_minMaxWidget->width()-m_minMaxBtn->width(),0,0,0);
 
-    m_mainWidgetLayout->setContentsMargins(0,0,0,0);
+    m_mainWidgetLayout->setContentsMargins(0,0,0,6);
 
     Q_FOREACH(QAbstractButton* button,m_buttonList)
     {
@@ -488,6 +572,14 @@ void SideBarWidget::loadMaxSidebar()
         setMaxSidebarBtn(btn);
     }
 
+    Q_FOREACH(QAbstractButton* button,m_buttonList)
+    {
+        QPushButton* btn=qobject_cast<QPushButton*>(button);
+        btn->setFixedSize(m_btnWidth,Style::SideBarBtnHeight);
+    }
+
+    changeIconColor(true);
+
     disconnect(m_minMaxBtn, &QToolButton::clicked,this,&SideBarWidget::sendFullScreenBtnSignal);
     connect(m_minMaxBtn, &QToolButton::clicked,this,&SideBarWidget::sendDefaultBtnSignal);
 }
@@ -497,14 +589,16 @@ void SideBarWidget::loadMaxSidebar()
  */
 void SideBarWidget::setMinBtn()
 {
+    const auto ratio=devicePixelRatioF();
+    QPixmap pixmap=loadSvg(QString(":/data/img/sidebarwidget/min.svg"),14*ratio);
+    pixmap=drawSymbolicColoredPixmap(pixmap);//反白
+    pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
+
     m_minMaxBtn->setFixedSize(Style::MinMaxBtnWidth,Style::MinMaxBtnWidth);
-    QSvgRenderer* svgRender = new QSvgRenderer(m_minMaxBtn);
-    svgRender->load(QString(":/data/img/sidebarwidget/min.svg"));
-    QPixmap* pixmap = new QPixmap(Style::MinMaxIconSize,Style::MinMaxIconSize);
-    pixmap->fill(Qt::transparent);//设置背景透明
-    QPainter p(pixmap);
-    svgRender->render(&p);
-    m_minMaxBtn->setIcon(QIcon(*pixmap));
+    m_minMaxBtn->setIcon(QIcon(pixmap));
+    m_minMaxBtn->setToolTip("");
+
+//    m_minMaxBtn->setFocus();
 }
 
 /**
@@ -524,87 +618,213 @@ void SideBarWidget::setMaxSidebarBtn(QPushButton *btn)
         layout->setSpacing(10);
     }
 
+     QLabel* labeltext=m_labelList.at(m_buttonList.indexOf(btn));
+     labeltext->setVisible(true);
+
     //修复修改字体大小时获取文本Label大小无效
     //移除按钮文本
-    QLayoutItem *child;
-    if((child = btn->layout()->takeAt(1)) != nullptr) {
-        QWidget* childwid=child->widget();
-        if(childwid!=nullptr)
-        {
-            btn->layout()->removeWidget(childwid);
-            childwid->setParent(nullptr);
-            delete childwid;
-            delete child;
-        }
-    }
+//    QLayoutItem *child;
+//    if((child = btn->layout()->takeAt(1)) != nullptr) {
+//        QWidget* childwid=child->widget();
+//        if(childwid!=nullptr)
+//        {
+//            btn->layout()->removeWidget(childwid);
+//            childwid->setParent(nullptr);
+//            delete childwid;
+//            delete child;
+//        }
+//    }
     //添加文本
-    QLabel* labeltext=new QLabel;
-    labeltext->setStyleSheet(QString("QLabel{background:transparent;color:#ffffff;border:0px;}"));
+//    QLabel* labeltext=new QLabel;
     if(m_buttonList.indexOf(btn)<=2)
     {
         labeltext->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
         labeltext->setText(m_textList.at(m_buttonList.indexOf(btn)));
         labeltext->adjustSize();
         m_btnWidth=44+labeltext->width()+10;
+        btn->setToolTip("");
     }
     else
     {
             QFont ft;
             QFontMetrics fm(ft);
-            QString text_1 = fm.elidedText(m_textList.at(m_buttonList.indexOf(btn)), Qt::ElideRight, m_btnWidth-44);
+            QString text = fm.elidedText(m_textList.at(m_buttonList.indexOf(btn)), Qt::ElideRight, m_btnWidth-44);
             labeltext->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-            labeltext->setText(text_1);
+            labeltext->setText(text);
             labeltext->setFixedSize(m_btnWidth-44,Style::SideBarBtnHeight);
             labeltext->adjustSize();
+            if(fm.boundingRect(m_textList.at(m_buttonList.indexOf(btn))).width()>labeltext->width())
+                btn->setToolTip(m_textList.at(m_buttonList.indexOf(btn)));
+            else
+                btn->setToolTip("");
     }
-
-    btn->layout()->addWidget(labeltext);
-    btn->setFixedSize(m_btnWidth,Style::SideBarBtnHeight);
-//    btn->setToolTip("");
+    QPalette pe = labeltext->palette();
+    pe.setColor(QPalette::ButtonText,QColor(Qt::white));
+    labeltext->setPalette(pe);
+//    btn->layout()->addWidget(labeltext);
 }
 
-void SideBarWidget::btnGroupClickedSlot(QAbstractButton *btn)
+void SideBarWidget::btnAllClickedSlot()
 {
-    char btncolor[300];
-    sprintf(btncolor,"QPushButton{background:transparent;border:0px;padding-left:0;border-radius:4px;}\
-            QPushButton:hover{background-color:%s;border:0px;border-radius:4px;}\
-            QPushButton:pressed{background-color:%s;border:0px;border-radius:4px;}",
-            SBFunBtnHoverBackground,SBFunBtnHoverBackground);
+    m_allBtn->setChecked(true);
+    m_letterBtn->setChecked(false);
+    m_functionBtn->setChecked(false);
+    if(m_isFullScreen)
+    {
+        Q_EMIT sendFullScreenCommonUseBtnSignal();
+        Q_EMIT setSlideBar(0);
+    }
+    else
+    {
+        Q_EMIT sendCommonUseBtnSignal();
+    }
+}
 
-    char pressstyle[200];
-    sprintf(pressstyle,"QPushButton{background-color:%s;border:0px;padding-left:0;border-radius:4px;}",SBClassifyBtnSelectedBackground);
+void SideBarWidget::btnLetterClickedSlot()
+{
+    m_allBtn->setChecked(false);
+    m_letterBtn->setChecked(true);
+    m_functionBtn->setChecked(false);
+    if(m_isFullScreen)
+    {
+        Q_EMIT sendFullScreenLetterBtnSignal();
+    }
+    else
+    {
+        Q_EMIT sendLetterBtnSignal();
+    }
+}
 
-    Q_FOREACH (QAbstractButton* button, m_buttonList) {
-        if(m_btnGroup->id(btn)==m_buttonList.indexOf(button))
+void SideBarWidget::btnFuncClickedSlot()
+{
+    m_allBtn->setChecked(false);
+    m_letterBtn->setChecked(false);
+    m_functionBtn->setChecked(true);
+
+    if(m_isFullScreen)
+    {
+        Q_EMIT sendFullScreenFunctionBtnSignal();
+    }
+    else
+    {
+        Q_EMIT sendFunctionBtnSignal();
+    }
+}
+
+void SideBarWidget::themeModeChangeSlot(QString styleName)
+{
+    if(styleName=="styleName")
+    {
+        QGSettings* gsetting=new QGSettings(QString("org.ukui.style").toLocal8Bit());
+        Q_FOREACH(QAbstractButton *button,m_buttonList)
         {
-            button->setStyleSheet(pressstyle);
-            if(m_btnGroup->id(btn)==0)
+            QPushButton *btn=qobject_cast<QPushButton*>(button);
+            QLayoutItem *item=btn->layout()->itemAt(0);
+            QLabel *label=qobject_cast<QLabel*>(item->widget());
+            QString iconStr;
+            switch (m_buttonList.indexOf(button)) {
+            case 0:
+                iconStr=QString(":/data/img/sidebarwidget/commonuse.svg");
+                break;
+            case 1:
+                iconStr=QString(":/data/img/sidebarwidget/letter.svg");
+                break;
+            case 2:
+                iconStr=QString(":/data/img/sidebarwidget/function.svg");
+                break;
+            case 3:
+                userAccountsChanged();
+                break;
+            case 4:
+                iconStr=QString(":/data/img/sidebarwidget/personal.svg");
+                break;
+            case 5:
+                iconStr=QString(":/data/img/sidebarwidget/trash.svg");
+                break;
+            case 6:
+                iconStr=QString(":/data/img/sidebarwidget/computer.svg");
+                break;
+            case 7:
+                iconStr=QString(":/data/img/sidebarwidget/setting.svg");
+                break;
+            case 8:
+                iconStr=QString(":/data/img/sidebarwidget/shutdown.svg");
+                break;
+            default:
+                break;
+            }
+            if(m_buttonList.indexOf(button)!=3)
             {
-                if(m_isFullScreen)
-                    Q_EMIT sendFullScreenCommonUseBtnSignal();
+                const auto ratio=devicePixelRatioF();
+                QPixmap pixmap=loadSvg(iconStr,19*ratio);
+                if(gsetting->get("style-name").toString()=="ukui-light")//反黑
+                    pixmap=drawSymbolicBlackColoredPixmap(pixmap);
                 else
-                    Q_EMIT sendCommonUseBtnSignal();
-            }
-            else if(m_btnGroup->id(btn)==1)
-            {
-                if(m_isFullScreen)
-                    Q_EMIT sendFullScreenLetterBtnSignal();
-                else Q_EMIT sendLetterBtnSignal();
-            }
-            else{
-                if(m_isFullScreen)
-                    Q_EMIT sendFullScreenFunctionBtnSignal();
-                else Q_EMIT sendFunctionBtnSignal();
+                    pixmap=drawSymbolicColoredPixmap(pixmap);//反白
+                pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
+                label->setPixmap(pixmap);
             }
         }
-        else{
-            button->setStyleSheet(btncolor);
+    }
+}
+
+void SideBarWidget::changeIconColor(bool isFullScreen)
+{
+    QGSettings* gsetting=new QGSettings(QString("org.ukui.style").toLocal8Bit());
+    Q_FOREACH(QAbstractButton *button,m_buttonList)
+    {
+        QPushButton *btn=qobject_cast<QPushButton*>(button);
+        QLayoutItem *item=btn->layout()->itemAt(0);
+        QLabel *label=qobject_cast<QLabel*>(item->widget());
+        QString iconStr;
+        switch (m_buttonList.indexOf(button)) {
+        case 0:
+            iconStr=QString(":/data/img/sidebarwidget/commonuse.svg");
+            break;
+        case 1:
+            iconStr=QString(":/data/img/sidebarwidget/letter.svg");
+            break;
+        case 2:
+            iconStr=QString(":/data/img/sidebarwidget/function.svg");
+            break;
+        case 3:
+            userAccountsChanged();
+            break;
+        case 4:
+            iconStr=QString(":/data/img/sidebarwidget/personal.svg");
+            break;
+        case 5:
+            iconStr=QString(":/data/img/sidebarwidget/trash.svg");
+            break;
+        case 6:
+            iconStr=QString(":/data/img/sidebarwidget/computer.svg");
+            break;
+        case 7:
+            iconStr=QString(":/data/img/sidebarwidget/setting.svg");
+            break;
+        case 8:
+            iconStr=QString(":/data/img/sidebarwidget/shutdown.svg");
+            break;
+        default:
+            break;
+        }
+        if(m_buttonList.indexOf(button)!=3)
+        {
+            const auto ratio=devicePixelRatioF();
+            QPixmap pixmap=loadSvg(iconStr,18*ratio);
+            if(gsetting->get("style-name").toString()=="ukui-light" && !isFullScreen)//反黑
+                pixmap=drawSymbolicBlackColoredPixmap(pixmap);
+            else
+                pixmap=drawSymbolicColoredPixmap(pixmap);//反白
+            pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
+            label->setPixmap(pixmap);
         }
     }
 }
 
 void SideBarWidget::enterAnimation()
 {
+    m_animation->stop();
     m_animation->setDuration(200);//动画总时间
     m_animation->setStartValue(QRect(this->width(),0,
                                     0,this->height()));
@@ -622,20 +842,6 @@ void SideBarWidget::setSideBarBtnGeometry()
     m_mainWidget->show();
 }
 
-void SideBarWidget::widgetMakeZero()
-{
-    char pressstyle[200];
-    sprintf(pressstyle,"QPushButton{background-color:%s;border:0px;padding-left:0;border-radius:4px;}",SBClassifyBtnSelectedBackground);
-    m_allBtn->setStyleSheet(pressstyle);
-    char btncolor[300];
-    sprintf(btncolor,"QPushButton{background:transparent;border:0px;padding-left:0;border-radius:4px;}\
-            QPushButton:hover{background-color:%s;border:0px;border-radius:4px;}\
-            QPushButton:pressed{background-color:%s;border:0px;border-radius:4px;}",
-            SBFunBtnHoverBackground,SBFunBtnHoverBackground);
-    m_letterBtn->setStyleSheet(btncolor);
-    m_functionBtn->setStyleSheet(btncolor);
-}
-
 //void SideBarWidget::mousePressEvent(QMouseEvent *event)
 //{
 //    if(m_isFullScreen && event->button()==Qt::LeftButton)
@@ -652,3 +858,66 @@ void SideBarWidget::widgetMakeZero()
 //                 this->parentWidget()->parentWidget()->hide();
 //    }
 //}
+
+void SideBarWidget::keyPressEvent(QKeyEvent* e)
+{
+    if(e->type()==QEvent::KeyPress)
+    {
+        switch(e->key())
+        {
+        case Qt::Key_Enter:
+        case Qt::Key_Return:
+        {
+            if(m_allBtn->hasFocus())
+            {
+                m_allBtn->click();
+            }
+            else if(m_letterBtn->hasFocus())
+            {
+                m_letterBtn->click();
+            }
+            else if(m_functionBtn->hasFocus())
+            {
+                m_functionBtn->click();
+            }
+            else
+            {
+                QWidget *current_focus_widget;
+                current_focus_widget = QWidget::focusWidget();
+                QPushButton *le= qobject_cast<QPushButton*>(current_focus_widget);
+                le->clicked();
+            }
+        }
+            break;
+        case Qt::Key_Down:
+            qDebug() << "SideBarWidget::keyPressEvent(QKeyEvent* e) key_Down";
+       //     focusNextChild();
+//            if(m_buttonList.at(2)->hasFocus())
+//            {
+//                m_buttonList.at(3)->setFocus();
+//            }
+//            if(m_shutDownBtn->hasFocus())
+//            {
+//                m_minMaxBtn->setFocus();
+//            }
+
+            break;
+        case Qt::Key_Up:
+            qDebug() << "SideBarWidget::keyPressEvent(QKeyEvent* e) key_Up";
+        // /*   focusPreviousChild();
+//            if(m_buttonList.at(0)->hasFocus())
+//            {
+//                m_minMaxBtn->setFocus();
+//            }
+            break;
+        default:
+            return QWidget::keyPressEvent(e);
+            break;
+        }
+    }
+}
+
+void SideBarWidget::setFocusToThis()
+{
+    this->setFocus();
+}
