@@ -51,10 +51,6 @@ public:
      * @brief Load the full-screen sidebar
      */
     void loadMaxSidebar();
-    /**
-     * @brief Initializes the interface state
-     */
-    void widgetMakeZero();
     /**
      * @brief Sidebar animation
      */
@@ -72,10 +68,10 @@ private:
 
     QWidget *m_minMaxWidget=nullptr;
     QHBoxLayout *m_minMaxLayout=nullptr;
-    QToolButton *m_minMaxBtn=nullptr;
+    QPushButton *m_minMaxBtn=nullptr;
 
-    QButtonGroup *m_btnGroup=nullptr;
     QList<QAbstractButton*> m_buttonList;
+    QList<QLabel*> m_labelList;
     QStringList m_textList;
     QPushButton *m_allBtn=nullptr;
     QPushButton *m_letterBtn=nullptr;
@@ -90,8 +86,8 @@ private:
     QSpacerItem *m_verticalSpacer=nullptr;
     bool m_isFullScreen=false;
     QGSettings *m_gsetting=nullptr;
-    RightClickMenu *m_shutDownMenu=nullptr;
-    RightClickMenu *m_otherMenu=nullptr;
+  //  RightClickMenu *m_shutDownMenu=nullptr;
+  //  RightClickMenu *m_otherMenu=nullptr;
     QPropertyAnimation* m_animation=nullptr;
 
     int m_btnWidth, m_btnheight;
@@ -138,22 +134,33 @@ protected:
      */
     void setMaxBtn();
     QPixmap PixmapToRound(const QPixmap &src, int radius);
+    void changeIconColor(bool isFullScreen);
 //    void mousePressEvent(QMouseEvent* event);
+    void keyPressEvent(QKeyEvent* e);
+
+    bool eventFilter(QObject * target , QEvent * event );
 
 private Q_SLOTS:
     /**
-     * @brief Respond to button click
-     * @param btn: QButtonGroup button
+     * @brief btnAllClickedSlot
      */
-    void btnGroupClickedSlot(QAbstractButton *btn);
+    void btnAllClickedSlot();
+    /**
+     * @brief btnLetterClickedSlot
+     */
+    void btnLetterClickedSlot();
+    /**
+     * @brief btnFuncClickedSlot
+     */
+    void btnFuncClickedSlot();
     /**
      * @brief Load power button right-click menu
      */
-    void shutdownBtnRightClickSlot();
+    void shutdownBtnRightClickSlot(const QPoint &pos);
     /**
      * @brief Load other application right-click menu
      */
-    void otherBtnRightClickSlot();
+    void otherBtnRightClickSlot(const QPoint &pos);
     /**
      * @brief Respond to computer btn
      */
@@ -186,6 +193,11 @@ private Q_SLOTS:
      * @brief Reset the sidebar button
      */
     void resetSidebarBtnSlot();
+    void themeModeChangeSlot(QString styleName);
+
+public Q_SLOTS:
+
+    void setFocusToThis();
 
 Q_SIGNALS:
     /**
@@ -224,6 +236,12 @@ Q_SIGNALS:
      * @brief Send a hidden main window signal to the MainWindow
      */
     void sendHideMainWindowSignal();
+
+    void sendShowMainWindowSignal(bool flag);
+
+    void setFocusToMainWin();
+
+    void setSlideBar(int value);
 };
 
 #endif // SIDEBARWIDGET_H
