@@ -17,6 +17,7 @@
  */
 
 #include "style.h"
+#include "src/UtilityFunction/utility.h"
 #include <QDebug>
 
 Style::Style()
@@ -24,6 +25,12 @@ Style::Style()
 
 }
 
+int Style::primaryScreenX=0;
+int Style::primaryScreenY=0;
+int Style::primaryScreenWidth=0;
+int Style::primaryScreenHeight=0;
+int Style::panelPosition=0;
+int Style::panelSize=0;
 //默认窗口
 int Style::minw=0;
 int Style::minh=0;
@@ -34,6 +41,7 @@ int Style::defaultQueryLineEditHeight=0;
 int Style::defaultQueryLineEditIconSize=0;
 int Style::defaultContentWidHeight=0;
 int Style::defaultSideBarWidWidth=0;
+int Style::defaultIconSize=32;
 /**
   * 全屏窗口
   */
@@ -75,7 +83,7 @@ int Style::AppSpaceBetweenIconText=0;
 int Style::AppBottomSpace=0;
 int Style::SliderSize=0;
 
-//侧边栏
+//侧边栏primaryScreen
 int Style::SideBarWidWidth=0;
 int Style::SideBarMargin=0;
 int Style::MinMaxWidWidth=0;
@@ -93,43 +101,33 @@ int Style::SideBarSpaceBetweenItem=0;
 
 void Style::initWidStyle()
 {
+
+    QVariantList list=getScreenGeometry();
+    if(list.count()>=6)
+    {
+        primaryScreenX=list.at(0).toInt();
+        primaryScreenY=list.at(1).toInt();
+        primaryScreenWidth=list.at(2).toInt();
+        primaryScreenHeight=list.at(3).toInt();
+        panelSize=list.at(4).toInt();
+        panelPosition=list.at(5).toInt();
+    }
+
     QGSettings* setting=new QGSettings(QString("org.mate.interface").toLocal8Bit());
     QString value=setting->get("font-name").toString();
     QStringList valstr=value.split(" ");
     int fontSize=valstr.at(valstr.count()-1).toInt();
 
-    int position=0;
-    int panelSize=0;
-    if(QGSettings::isSchemaInstalled(QString("org.ukui.panel.settings").toLocal8Bit()))
+    if(panelPosition==0 || panelPosition==1)
     {
-        QGSettings* gsetting=new QGSettings(QString("org.ukui.panel.settings").toLocal8Bit());
-        if(gsetting->keys().contains(QString("panelposition")))
-            position=gsetting->get("panelposition").toInt();
-        else
-            position=0;
-        if(gsetting->keys().contains(QString("panelsize")))
-            panelSize=gsetting->get("panelsize").toInt();
-        else
-            panelSize=46;
+        widthavailable=primaryScreenWidth;
+        heightavailable=primaryScreenHeight-panelSize;
     }
-    else
+    if(panelPosition==2 || panelPosition==3)
     {
-        position=0;
-        panelSize=46;
+        widthavailable=primaryScreenWidth-panelSize;
+        heightavailable=primaryScreenHeight;
     }
-
-
-    if(position==0 || position==1)
-    {
-        widthavailable=QApplication::primaryScreen()->geometry().width();
-        heightavailable=QApplication::primaryScreen()->geometry().height()-panelSize;
-    }
-    if(position==2 || position==3)
-    {
-        widthavailable=QApplication::primaryScreen()->geometry().width()-panelSize;
-        heightavailable=QApplication::primaryScreen()->geometry().height();
-    }
-
     int len=0;
     QString locale = QLocale::system().name();
     if (locale == "zh_CN")
@@ -137,8 +135,7 @@ void Style::initWidStyle()
     else
         len=10;
 
-    if(QApplication::primaryScreen()->geometry().width()==800 &&
-            QApplication::primaryScreen()->geometry().height()==600)
+    if(primaryScreenWidth==800 && primaryScreenHeight==600)
     {
         minw=320;
         minh=500;
@@ -178,7 +175,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=14;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=15;
@@ -224,7 +221,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=14;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=15;
@@ -270,7 +267,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=11;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=10;
@@ -316,7 +313,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=11;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=10;
@@ -362,7 +359,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=11;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=10;
@@ -408,7 +405,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=11;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=10;
@@ -454,7 +451,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=11;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=10;
@@ -500,7 +497,7 @@ void Style::initWidStyle()
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
         LeftFontSize=fontSize;
         LeftLetterFontSize=11;
-        LeftIconSize=19;
+        LeftIconSize=17;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=10;
