@@ -17,14 +17,13 @@
  */
 
 #include "fullitemdelegate.h"
+#include "src/UtilityFunction/utility.h"
 #include <QDebug>
 
 FullItemDelegate::FullItemDelegate(QObject *parent, int module):
     QStyledItemDelegate(parent)
 {
     this->module=module;
-    QString path=QDir::homePath()+"/.config/ukui/ukui-menu.ini";
-    setting=new QSettings(path,QSettings::IniFormat);
     pUkuiMenuInterface=new UkuiMenuInterface;
 }
 
@@ -37,7 +36,6 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 {
     if(index.isValid())
     {
-        painter->save();
         QStyleOptionViewItem viewOption(option);//用来在视图中画一个item
         QRectF rect;
         rect.setX(option.rect.x());
@@ -58,19 +56,20 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
         path.lineTo(rect.topRight() + QPointF(0, radius));
         path.quadTo(rect.topRight(), rect.topRight() + QPointF(-radius, -0));
 
-//        painter->setRenderHint(QPainter::Antialiasing);
-//        if(option.state.testFlag(QStyle::State_Selected))
-//        if(option.state & QStyle::State_MouseOver)
-//        {
-//            painter->setPen(QPen(Qt::NoPen));
-//            QColor color;
-//            color.setNamedColor(QString::fromLocal8Bit(AppBtnHover));
-//            painter->setBrush(QBrush(color));
-
-//            painter->setOpacity(0.14);
-//            painter->drawPath(path);
-//        }
+        painter->setRenderHint(QPainter::Antialiasing);
+        if((option.state & QStyle::State_MouseOver) || (option.state & QStyle::State_HasFocus))
+        {
+//            QColor color = option.palette.text().color();
+//            color.setAlphaF(0.15);
+            painter->save();
+            painter->setPen(QPen(Qt::NoPen));
+            painter->setBrush(Qt::white);
+            painter->setOpacity(0.15);
+            painter->drawPath(path);
+            painter->restore();
+        }
 
+        painter->save();
         painter->setOpacity(1);
         QString desktopfp=index.data(Qt::DisplayRole).value<QString>();
         QString iconstr=pUkuiMenuInterface->getAppIcon(desktopfp);
@@ -83,12 +82,17 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
             iconstr.remove(".png");
             iconstr.remove(".svg");
             icon=QIcon::fromTheme(iconstr);
-            if(icon.isNull())
+            if(icon.isNull() || icon.actualSize(QSize(Style::AppListIconSize,
+                                                      Style::AppListIconSize)).width() < Style::AppListIconSize)
             {
                 if(QFile::exists(QString("/usr/share/icons/hicolor/scalable/apps/%1.%2").arg(iconstr).arg("svg")))
                     icon=QIcon(QString("/usr/share/icons/hicolor/scalable/apps/%1.%2").arg(iconstr).arg("svg"));
                 else if(QFile::exists(QString("/usr/share/icons/hicolor/scalable/apps/%1.%2").arg(iconstr).arg("png")))
                     icon=QIcon(QString("/usr/share/icons/hicolor/scalable/apps/%1.%2").arg(iconstr).arg("png"));
+                else if(QFile::exists(QString("/usr/share/icons/hicolor/128x128/apps/%1.%2").arg(iconstr).arg("png")))
+                    icon=QIcon(QString("/usr/share/icons/hicolor/128x128/apps/%1.%2").arg(iconstr).arg("png"));
+                else if(QFile::exists(QString("/usr/share/icons/hicolor/128x128/apps/%1.%2").arg(iconstr).arg("svg")))
+                    icon=QIcon(QString("/usr/share/icons/hicolor/128x128/apps/%1.%2").arg(iconstr).arg("svg"));
                 else if(QFile::exists(QString("/usr/share/icons/hicolor/96x96/apps/%1.%2").arg(iconstr).arg("png")))
                     icon=QIcon(QString("/usr/share/icons/hicolor/96x96/apps/%1.%2").arg(iconstr).arg("png"));
                 else if(QFile::exists(QString("/usr/share/icons/hicolor/96x96/apps/%1.%2").arg(iconstr).arg("svg")))
@@ -105,6 +109,14 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
                     icon=QIcon(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("png"));
                 else if(QFile::exists(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("svg")))
                     icon=QIcon(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("svg"));
+                else if(QFile::exists(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("png")))
+                    icon=QIcon(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("png"));
+                else if(QFile::exists(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("svg")))
+                    icon=QIcon(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("svg"));
+                else if(QFile::exists(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("xpm")))
+                    icon=QIcon(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("xpm"));
+                else if(QFile::exists(QString("/usr/share/icons/%1.%2").arg(iconstr).arg("png")))
+                    icon=QIcon(QString("/usr/share/icons/%1.%2").arg(iconstr).arg("png"));
                 else
                     icon=QIcon::fromTheme(QString("application-x-desktop"));
             }
@@ -119,32 +131,35 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
                        Style::AppListIconSize,
                        Style::AppListIconSize);
         icon.paint(painter,iconRect);
+        painter->restore();
+
+        painter->save();
+        bool is_locked=false;
+        QFileInfo fileInfo(desktopfp);
+        QString desktopfn=fileInfo.fileName();
+        //添加固定图标
+        if(module==0)
+        {
+            if(checkIfLocked(desktopfn))
+            {
+                is_locked=true;
+                QIcon icon(QString(":/data/img/mainviewwidget/lock-fs.svg"));
+                icon.paint(painter,QRect(iconRect.topRight().x()-14,iconRect.topRight().y()-2,16,16));
+            }
+        }
+        painter->restore();
 
         textRect=QRect(rect.x()+5,
                        iconRect.bottom()+Style::AppSpaceBetweenIconText,
                        rect.width()-10,
                        rect.height()-iconRect.height()-Style::AppSpaceBetweenIconText);
 
-        bool is_locked=false;
+        painter->save();
+        //添加最近安装蓝色标签
         bool is_recentapp=false;
-        QFileInfo fileInfo(desktopfp);
-        QString desktopfn=fileInfo.fileName();
         QFontMetrics fm=painter->fontMetrics();
         QString appnameElidedText=fm.elidedText(appname,Qt::ElideRight,rect.width()-10,Qt::TextShowMnemonic);
-
-        if(module==0)
-        {
-            setting->beginGroup("lockapplication");
-            if(setting->contains(desktopfn))
-            {
-                is_locked=true;
-                QIcon icon(QString(":/data/img/mainviewwidget/lock-fs.svg"));
-                icon.paint(painter,QRect(iconRect.topRight().x()-14,iconRect.topRight().y()-2,16,16));
-            }
-            setting->endGroup();
-        }
-        setting->beginGroup("recentapp");
-        if(setting->contains(desktopfn) && !is_locked)
+        if(checkIfRecent(desktopfn) && !checkIfLocked(desktopfn))
         {
             is_recentapp=true;
             appnameElidedText=fm.elidedText(appname,Qt::ElideRight,rect.width()-23,Qt::TextShowMnemonic);
@@ -167,23 +182,18 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
                                  4);
 
         }
-        setting->endGroup();
+        painter->restore();
 
+        painter->save();
+//        painter->setPen(QPen(option.palette.text().color()));
         painter->setPen(QPen(Qt::white));
+        painter->setBrush(Qt::NoBrush);
         painter->drawText(textRect,Qt::AlignHCenter |Qt::AlignTop,appnameElidedText);
+//        painter->drawText(textRect,Qt::TextWordWrap |Qt::AlignHCenter,appname);
+        painter->restore();
 
-        painter->setRenderHint(QPainter::Antialiasing);
-//        if(option.state.testFlag(QStyle::State_Selected))
-        if(option.state & QStyle::State_MouseOver)
+        if((option.state & QStyle::State_MouseOver) || (option.state & QStyle::State_HasFocus))
         {
-            painter->setPen(QPen(Qt::NoPen));
-            QColor color;
-            color.setNamedColor(QString::fromLocal8Bit(AppBtnHover));
-            painter->setBrush(QBrush(color));
-
-            painter->setOpacity(0.14);
-            painter->drawPath(path);
-
             int len=0;
             if(!is_locked && is_recentapp)
                 len=fm.boundingRect(appname).width()+23;
@@ -193,12 +203,10 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
             {
                 QToolTip::showText(QCursor::pos(),appname);
             }
+            else {
+                QToolTip::hideText();
+            }
         }
-        else {
-            QToolTip::hideText();
-        }
-        painter->restore();
-
     }
 }
 
