@@ -30,6 +30,9 @@
 
 #define DATABASENAME QDir::homePath()+"/.config/ukui/"+"UkuiMenu.db"
 
+bool isHuaWeiPC = false;
+bool isHuaWei9006C = false;
+
 const QPixmap loadSvg(const QString &fileName, const int size)
 {
     QPixmap pixmap(size, size);
@@ -515,14 +518,14 @@ void execApp(QString desktopfp)
 
 bool checkOsRelease()
 {
-    QFile file("/etc/os-release");
-    if(file.open(QFile::ReadOnly))
-    {
-        QByteArray line=file.readLine();
-        file.close();
-        if(QString(line).contains("Ubuntu"))
-            return true;
-    }
+//    QFile file("/etc/os-release");
+//    if(file.open(QFile::ReadOnly))
+//    {
+//        QByteArray line=file.readLine();
+//        file.close();
+//        if(QString(line).contains("Ubuntu"))
+//            return true;
+//    }
     return false;
 }
 
